pub struct ChitchatEnvelope {
pub version: ProtocolVersion,
pub message: ChitchatMessage,
}Expand description
A ChitchatMessage paired with the protocol version it is encoded
with. The version is not part of the message model (see
ChitchatMessage’s doc); this struct is the unit that actually travels
on the wire, see message_serialize.
Fields
version: ProtocolVersionmessage: ChitchatMessageTrait Implementations
Sourceimpl Debug for ChitchatEnvelope
impl Debug for ChitchatEnvelope
impl Eq for ChitchatEnvelope
Sourceimpl PartialEq for ChitchatEnvelope
impl PartialEq for ChitchatEnvelope
impl StructuralPartialEq for ChitchatEnvelope